@@ -8,15 +8,7 @@
 #
 ################################################################################
 #
-# $Project: /Convert-Binary-C $
-# $Author: mhx $
-# $Date: 2009/03/15 04:10:45 +0100 $
-# $Revision: 17 $
-# $Source: /token/pragma.pl $
-#
-################################################################################
-#
-# Copyright (c) 2002-2009 Marcus Holland-Moritz. All rights reserved.
+# Copyright (c) 2002-2024 Marcus Holland-Moritz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -24,8 +16,8 @@
 
 use Devel::Tokenizer::C;
 
-$t = new Devel::Tokenizer::C TokenFunc => \&tok_code,
-                             TokenEnd  => 'PRAGMA_TOKEN_END';
+$t = Devel::Tokenizer::C->new(TokenFunc => \&tok_code,
+                              TokenEnd  => 'PRAGMA_TOKEN_END');
 
 $t->add_tokens( qw(
   pack
